<?php
// $Horde: horde/lib/MIME/Viewer/postscript.php,v 1.7.2.1 2001/12/23 20:19:07 chuck Exp $

/**
 * The MIME_Viewer_postscript class renders out various content
 * in HTML format by using 
 *
 * @author  Anil Madhavapeddy <anil@recoil.org>
 * @version $Revision: 1.7.2.1 $
 * @since   Horde 1.3
 * @package horde.mime.viewer
 */
class MIME_Viewer_postscript extends MIME_Viewer {

    /**
     * Render out the currently set contents using webify
     * The $mime_part class variable has the information to render
     * out, encapsulated in a MIME_Part object.
     * @return string HTML pretty-print of the content
     */
    function render($params = null)
    {
        global $mime_drivers;

        /* Create temporary file for input */

        $tmpin = Horde::getTempFile() . '.ps';

		/* Extract some configuration stuff */

        $tempdir = $mime_drivers['horde']['postscript']['tempdir'];
		$location = $mime_drivers['horde']['postscript']['location'];
		$gslocation = $mime_drivers['horde']['postscript']['gslocation'];
		$hackppmlocation = $mime_drivers['horde']['postscript']['hackppmlocation'];
		$slidesize = $mime_drivers['horde']['postscript']['slidesize'];
		$thumbsize = $mime_drivers['horde']['postscript']['thumbsize'];
		$webifytemplate = $mime_drivers['horde']['postscript']['template'];

		/* Get a name for an output directory */
		/* NB. This has to be accessible by a URL !! */
		/* Also remember that we probably need one per document */
		/* Who will clean the mess up later ?? */

        $URLdir = './' . basename($tempdir);
        $outdir = tempnam($tempdir, "PsOut");
        $outURL = $URLdir . '/' . basename($outdir);

		/* We want a dir, not a file, so destroy the file, only using the name */
		unlink($outdir);
		chdir($tempdir);

        /* Write the contents of our buffer to the temporary input file */
        $fout = fopen($tmpin, 'wb');
        $contents = $this->mime_part->getContents();
        fwrite($fout, $contents, strlen($contents));
        fclose($fout);

        /* Execute the webify command */ 
        exec(escapeShellCmd("$location -T$thumbsize -S$slidesize  -G$gslocation -H$hackppmlocation $webifytemplate $tmpin $outdir" ));

		/* Output the index file for the inline part */
        $fin = fopen($outdir . "/index.html", "r");
        $results = '';
        while ($chunk = fread($fin, 4096)) {
            $results .= $chunk;
        }

        /* Clean up the paths to the pictures as webify doesn't seem able to do this */

		$results = ereg_replace('href="', 'target="_blank" href="' . $outURL . '/', $results);
		$results = ereg_replace('SRC="', 'SRC="' . $outURL . '/', $results);

		/* Clean out the temfile we don't need any more */
		/* (We do need the outdir stuff though */
		unlink($tmpin);

        return '<pre>' . $results . '</pre>';
    }

    function getType()
    {
        return 'text/html';
    }

}
